.. _credits:

Credits
=======

The `Python bindings of JGraphT <https://github.com/d-michail/python-jgrapht>`_ and
the `JGraphT-capi <https://github.com/d-michail/jgrapht-capi>`_
project have been written by `Dimitrios Michail <https://github.com/d-michail>`_.

Refactoring of the build system and CI/CD pipelines for Linux, Windows,
and MacOSX contributed by `Fotis Tsamis <https://github.com/ftsamis>`_.

For the authors of the backend JGraphT library, see https://jgrapht.org and 
https://github.com/jgrapht/jgrapht/blob/master/CONTRIBUTORS.md.

